@@ -1064,7 +1064,8 @@ class ExportController(object):
             },
             'brillouin': {
                 'export': True,
-                'shift': {
+                'parameters': ['brillouin_shift_f'],
+                'brillouin_shift_f': {
                     'cax': ('min', 'max'),
                 }
             },
